@@ -22,19 +22,32 @@ class Doge(object):
     # wow pls extend this if you see it
     known_processes = (
         # wow shells and terminals and etc
-        'zsh', 'urxvt', 'tmux', 'fish', 'ssh', 'mutt',
+        'zsh', 'urxvt', 'tmux', 'fish', 'ssh', 'mutt', 'screen', 'mosh-client',
 
         # pretty browsers
-        'chromium', 'luakit', 'uzbl-core', 'firefox', 'jumanji',
+        'chromium', 'luakit', 'uzbl-core', 'firefox', 'jumanji', 'chrome',
+        'thunderbird',
 
         # many wms (borrow from djmelik/archey)
         'awesome', 'beryl', 'blackbox', 'bspwm', 'compiz', 'dwm',
         'enlightenment', 'herbstluftwm', 'fluxbox', 'fvwm', 'i3', 'icewm',
         'kwin', 'metacity', 'musca', 'openbox', 'pekwm', 'ratpoison',
         'scrotwm', 'wmaker', 'wmfs', 'wmii', 'xfwm4', 'xmonad',
+        'gnome-shell', 'devilspie2',
 
         # such services and daemons
-        'mpd', 'nginx', 'dzen2', 'systemd'
+        'mpd', 'nginx', 'dzen2', 'systemd', 'lighttpd', 'prosody',
+        'mongod', 'postgres', 'mysqld', 'redis-server', 'php-fpm',
+        'sendmail', 'irssi', 'screen', 'neo4j', 'httpd',
+        
+        # programming languages
+        'ruby', 'python', 'java', 'php',
+        
+        # so editors
+        'emacs', 'vim', 'nano', 'gedit', 'sublime_text',
+
+        # shells
+        'sh', 'bash', 'zsh'
     )
 
     def __init__(self, tty, doge_path=default_doge):
@@ -56,8 +69,6 @@ class Doge(object):
         if self.tty.width < max_doge:
             sys.stderr.write('wow, such small terminal\n')
             sys.stderr.write('no doge under {0} column\n'.format(max_doge))
-            sys.stderr.flush()
-
             sys.exit(1)
 
         # so many line
@@ -146,7 +157,9 @@ class Doge(object):
 
         finally:
             # wow no ps or many error
-            return procs
+            proc_list = list(procs)
+            random.shuffle(proc_list)
+            return proc_list
 
     def generate(self):
         for line in self.lines:
@@ -157,17 +170,19 @@ class Doge(object):
 class DogeMessage(object):
     prefixes = [
         'wow', 'such', 'very', 'so much', 'many', 'lol', 'beautiful',
-        'all the', 'the', 'most', 'very much', 'pretty'
+        'all the', 'the', 'most', 'very much', 'pretty', 'so'
     ]
 
     words = [
         'computer', 'hax0r', 'code', 'data', 'internet', 'server',
         'hacker', 'terminal', 'doge', 'shibe', 'program', 'free software',
-        'web scale', 'monads', 'git', 'daemon'
+        'web scale', 'monads', 'git', 'daemon', 'cloud computing', 'real-time',
+        'cloud', 'loop', 'big data', 'synergy', 'agile', 'viral', 'ROI',
+        'innovative'
     ]
 
     suffixes = [
-        'wow', 'lol', 'hax'
+        'wow', 'lol', 'hax', 'plz'
     ]
 
     def __init__(self, tty, occupied, word=None):
